# 1.2.0

- Added `prismarine version` command to print the version of Prismarine
- Changed `generate-client` command syntax to be more consistent with other commands
- Ensured deterministic generation of client code

# 1.1.0

- Integration with EasySAM
- Added export decorator

# 1.0.0

- First published version
